@@ -1,5 +1,5 @@
 /*-
- * Copyright (c) 2008, 2009, 2012, 2013, 2016 - 2019  Peter Pentchev
+ * Copyright (c) 2008, 2009, 2012, 2013, 2016 - 2019, 2021  Peter Pentchev
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -38,7 +38,6 @@
 #endif
 
 #include "confget.h"
-#include "confget_http_get.h"
 #include "confget_ini.h"
 
 struct var {
@@ -73,7 +72,6 @@ size_t			 varsalloc, varscount;
 struct var		*vars;
 
 static const confget_backend	* const backends[] = {
-	&confget_http_get_backend,
 	&confget_ini_backend,
 };
 #define BACKEND_CNT	(sizeof(backends) / sizeof(backends[0]))
@@ -83,7 +81,7 @@ static void		 init(int _argc, char * const *_argv);
 static void		 usage(bool _error);
 static void		 version(void);
 
-/* The currently used configuration backend (ini, http_get, etc.) */
+/* The currently used configuration backend (ini, etc.) */
 const confget_backend	*backend;
 
 /* The currently processed input file */
@@ -610,10 +608,20 @@ foundvar(const char * const sec, const char * const name,
 	varscount++;
 }
 
+static int
+compare_by_name(const void * const left, const void * const right)
+{
+	const struct var * const vleft = left;
+	const struct var * const vright = right;
+
+	return strcmp(vleft->name, vright->name);
+}
+
 static void
 displayvars(void)
 {
 	cfound = false;
+	qsort(vars, varscount, sizeof(vars[0]), compare_by_name);
 	for (size_t i = 0; i < varscount; i++)
 	{
 		if (!vars[i].display)
